@@ -26,7 +26,7 @@
 
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -128,7 +128,7 @@ typedef struct monitor_t {
 
 typedef struct diskperf_t {
     XfcePanelPlugin *plugin;
-    unsigned int    iTimerId;	/* Cyclic update */
+    guint           iTimerId;	/* Cyclic update */
     struct conf_t   oConf;
     struct monitor_t
                     oMonitor;
@@ -281,16 +281,21 @@ static int DisplayPerf (struct diskperf_t *p_poPlugin)
 
 	/**************************************************************/
 
-static gboolean SetTimer (void *p_pvPlugin)
+static gboolean Timer (gpointer user_data)
+{
+    struct diskperf_t *poPlugin = user_data;
+
+    DisplayPerf (poPlugin);
+    return TRUE;
+}
+
+static void SetTimer (diskperf_t *poPlugin)
 	/* Recurrently update the panel-docked monitor bars through a
 	   timer */
 {
     GtkSettings *settings;
-    struct diskperf_t *poPlugin = (diskperf_t *) p_pvPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
 
-    DisplayPerf (poPlugin);
-    
     if (timerNeedsUpdate) {
         g_source_remove (poPlugin->iTimerId);
         poPlugin->iTimerId = 0;
@@ -305,9 +310,7 @@ static gboolean SetTimer (void *p_pvPlugin)
                      poConf->iPeriod_ms - 10, NULL);
 
     if (!poPlugin->iTimerId)
-        poPlugin->iTimerId = g_timeout_add (poConf->iPeriod_ms,
-					    (GSourceFunc) SetTimer, poPlugin);
-    return TRUE;
+        poPlugin->iTimerId = g_timeout_add (poConf->iPeriod_ms, Timer, poPlugin);
 }				/* SetTimer() */
 
 	/**************************************************************/
@@ -884,6 +887,7 @@ static void UpdateConf (diskperf_t *poPlugin)
     SetDevice (poGUI->wTF_Device, poPlugin);
     SetLabel (poGUI->wTF_Title, poPlugin);
     SetXferRate (poGUI->wTF_MaxXfer, poPlugin);
+    DisplayPerf (poPlugin);
     SetTimer (poPlugin);
 }				/* UpdateConf() */
 
@@ -944,7 +948,7 @@ static void About (Widget_t w, void *unused)
       "version", PACKAGE_VERSION,
       "program-name", PACKAGE_NAME,
       "comments", _("Diskperf monitor displays instantaneous disk I/O transfer rates and busy times"),
-      "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-diskperf-plugin",
+      "website", "https://docs.xfce.org/panel-plugins/xfce4-diskperf-plugin",
       "copyright", _("Copyright (c) 2003, 2004 Roger Seguin"),
       "authors", auth, NULL);
    if(icon)
@@ -1187,6 +1191,7 @@ static void diskperf_construct (XfcePanelPlugin *plugin)
     diskperf_read_config (plugin, diskperf);
     DevPerfInit();
     
+    DisplayPerf (diskperf);
     SetTimer (diskperf);
 }
 
